@@ -4,16 +4,16 @@ Run `python -m pytest tests/e2e/test_spyre_warmup_shapes.py`.
 """
 
 import pytest
-from llm_cache import DecodeWarmupShapes
-from spyre_util import (check_output_against_hf, generate_spyre_vllm_output,
-                        get_chicken_soup_prompts)
+from output_util import check_output_against_hf, generate_spyre_vllm_output
+from spyre_util import DecodeWarmupShapes, ModelInfo, get_chicken_soup_prompts
 from vllm import SamplingParams
 
 
 @pytest.mark.parametrize(
     "warmup_shapes", [[(64, 20, 4),
                        (128, 20, 2)]])  # (prompt_length/new_tokens/batch_size)
-def test_multiple_warmup_shapes(model: str, warmup_shapes: DecodeWarmupShapes,
+def test_multiple_warmup_shapes(model: ModelInfo,
+                                warmup_shapes: DecodeWarmupShapes,
                                 backend: str, monkeypatch: pytest.MonkeyPatch,
                                 use_llm_cache) -> None:
     '''
@@ -57,7 +57,7 @@ def test_multiple_warmup_shapes(model: str, warmup_shapes: DecodeWarmupShapes,
 
 @pytest.mark.parametrize("prompts", [["Hello"]])
 @pytest.mark.parametrize("warmup_shapes", [[(65, 1, 1)]])
-def test_invalid_prompt_len(model: str, prompts: list[str],
+def test_invalid_prompt_len(model: ModelInfo, prompts: list[str],
                             warmup_shapes: DecodeWarmupShapes, backend: str,
                             monkeypatch: pytest.MonkeyPatch,
                             use_llm_cache) -> None:
