@@ -1,4 +1,5 @@
 import inspect
+import json
 import math
 import os
 import random
@@ -15,8 +16,6 @@ from transformers import AutoTokenizer
 from vllm import SamplingParams
 from vllm.entrypoints.openai.cli_args import make_arg_parser
 from vllm.utils import FlexibleArgumentParser, get_open_port
-from vllm.v1.engine import EngineCoreRequest
-from vllm.v1.engine.core import EngineCore
 from vllm.v1.request import Request
 
 EmbeddingWarmupShapes = list[tuple[int, int]]
@@ -58,6 +57,7 @@ def patch_warmup_shapes(warmup_shapes: DecodeWarmupShapes
 class ModelInfo(NamedTuple):
     name: str
     revision: str | None = None
+    is_quantized: bool = False
 
     def __str__(self):
         return f"ModelInfo({self.name}@{self.revision})"
@@ -198,14 +198,12 @@ def get_spyre_model_dir_path() -> Path:
     return Path(model_dir_path)
 
 
-# get model backends from env or default to all and add pytest markers
+# add pytest markers to supported different backends
 def get_spyre_backend_list():
-    user_backend_list = os.environ.get("VLLM_SPYRE_TEST_BACKEND_LIST",
-                                       "eager,inductor,sendnn")
+    backend_list = ["eager", "inductor", "sendnn"]
 
     backends = []
-    for backend in user_backend_list.split(","):
-        backend = backend.strip()
+    for backend in backend_list:
         marks = []
         if backend == "eager":
             marks = [pytest.mark.cpu]
@@ -270,7 +268,8 @@ def _default_test_models(isEmbeddings=False, isScoring=False):
         revision="6e9c6465a9d7e5e9fa35004a29f0c90befa7d23f")
     tinygranite_fp8 = ModelInfo(
         name="ibm-ai-platform/micro-g3.3-8b-instruct-1b-FP8",
-        revision="0dff8bacb968836dbbc7c2895c6d9ead0a05dc9e")
+        revision="0dff8bacb968836dbbc7c2895c6d9ead0a05dc9e",
+        is_quantized=True)
     params = [
         pytest.param(tinygranite,
                      marks=[pytest.mark.decoder],
@@ -332,7 +331,7 @@ def create_random_request(
     sampling_params: SamplingParams,
     from_model_vocab: bool = False,
     model: Optional[str] = None,
-) -> Request | EngineCoreRequest:
+) -> Request:
 
     tokenizer = AutoTokenizer.from_pretrained(model)
     if from_model_vocab:
@@ -354,40 +353,31 @@ def create_random_request(
         assert (len(prompt_token_ids) == num_tokens
                 ), f"need {num_tokens} but got {len(prompt_token_ids)}"
 
-    sig = inspect.signature(EngineCore.add_request)
-    inputs_renamed = hasattr(EngineCoreRequest, 'mm_kwargs')
-    if sig.parameters["request"].annotation == EngineCoreRequest:
-        kwargs = {"mm_kwargs" if inputs_renamed else "mm_inputs": None}
-        return EngineCoreRequest(
-            request_id=str(request_id),
-            prompt_token_ids=prompt_token_ids,
-            mm_hashes=None,
-            mm_placeholders=None,
-            sampling_params=sampling_params,
-            eos_token_id=None,
-            arrival_time=time.monotonic(),
-            lora_request=None,
-            data_parallel_rank=None,
-            pooling_params=None,
-            cache_salt=None,
-            **kwargs,
-        )
-    kwargs = {
-        "multi_modal_kwargs" if inputs_renamed else "multi_modal_inputs": None
-    }
-    return Request(
-        request_id=str(request_id),
-        prompt_token_ids=prompt_token_ids,
-        multi_modal_hashes=None,
-        multi_modal_placeholders=None,
-        sampling_params=sampling_params,
-        eos_token_id=None,
-        arrival_time=time.monotonic(),
-        lora_request=None,
-        pooling_params=None,
-        cache_salt=None,
-        **kwargs,
-    )
+    # temporary backward compat code for 0.10.1.1
+    annotations = inspect.getfullargspec(Request).annotations
+    extra_args = {}  # noqa
+    if ('multi_modal_hashes' in annotations):
+        extra_args.update({
+            'multi_modal_hashes': None,
+        })
+    if ('multi_modal_placeholders' in annotations):
+        extra_args.update({
+            'multi_modal_placeholders': None,
+        })
+    if ('multi_modal_kwargs' in annotations):
+        extra_args.update({
+            'multi_modal_kwargs': None,
+        })
+
+    return Request(request_id=str(request_id),
+                   prompt_token_ids=prompt_token_ids,
+                   sampling_params=sampling_params,
+                   eos_token_id=None,
+                   arrival_time=0,
+                   lora_request=None,
+                   pooling_params=None,
+                   cache_salt=None,
+                   **extra_args)
 
 
 def skip_unsupported_tp_size(size: int, backend: str):
@@ -461,3 +451,12 @@ def get_longer_chicken_soup_prompts(num_prompts: int) -> list[str]:
         prompts = prompts * (math.ceil(num_prompts / 4))
 
     return prompts[:num_prompts]
+
+
+def write_sample_model_config(tmp_path,
+                              data,
+                              filename="model_compile.log.json"):
+    """Helper to write a sample model_compile.log.json in tmp_path."""
+    config_path = tmp_path / filename
+    config_path.write_text(json.dumps(data))
+    return config_path
