@@ -7,11 +7,11 @@ import pytest
 import torch
 from vllm.sampling_params import SamplingParams
 from vllm.utils import is_pin_memory_available, make_tensor_with_pad
-from vllm.v1.sample.logits_processor import BatchUpdateBuilder
+from vllm.v1.sample.logits_processor import LogitsProcessors
 from vllm.v1.sample.metadata import SamplingMetadata
 
-from vllm_spyre.v1.worker.spyre_input_batch import (
-    SamplingInputBatch, SamplingRequestState, get_builtin_logits_processors)
+from vllm_spyre.v1.worker.spyre_input_batch import (SamplingInputBatch,
+                                                    SamplingRequestState)
 
 VOCAB_SIZE = 1024
 NUM_OUTPUT_TOKENS = 20
@@ -63,19 +63,12 @@ def _construct_expected_sampling_metadata(
                                          dtype=torch.bool,
                                          device=device)
 
-    batch_update_builder = BatchUpdateBuilder()
-    logitsprocs = get_builtin_logits_processors(vllm_config=None)
-
     bad_words_token_ids = {}
     for req in reqs:
         if req.req_id not in req_ids_retained:
             continue
         index_in_input_batch = input_batch.req_id_to_dense_index(req.req_id)
 
-        params = req.sampling_params
-        batch_update_builder.added.append(
-            (index_in_input_batch, params, req.output_token_ids))
-
         output_token_ids[index_in_input_batch] = req.output_token_ids
         prompt_token_ids[index_in_input_batch] = req.prompt_token_ids
         presence_penalties[
@@ -94,10 +87,6 @@ def _construct_expected_sampling_metadata(
             bad_words_token_ids[
                 index_in_input_batch] = req.sampling_params.bad_words_token_ids
 
-    batch_update = batch_update_builder.get_and_reset(num_reqs)
-    for logit_proc in logitsprocs.all:
-        logit_proc.update_state(batch_update)
-
     return SamplingMetadata(
         temperature=torch.tensor(temperature, dtype=torch.float,
                                  device=device),
@@ -130,7 +119,7 @@ def _construct_expected_sampling_metadata(
                       and all(x == 1 for x in repetition_penalties)),
         allowed_token_ids_mask=allowed_token_ids_mask,
         bad_words_token_ids=bad_words_token_ids,
-        logitsprocs=logitsprocs,
+        logitsprocs=LogitsProcessors(),
     )
 
 
