@@ -22,6 +22,8 @@ if TYPE_CHECKING:
     VLLM_SPYRE_MAX_LOAD_PROCESSES: int = 0
     VLLM_SPYRE_WORKER_LOG_REDIRECT_DIR: str = ""
     VLLM_SPYRE_GLOO_TIMEOUT_MINUTES: int = 60
+    VLLM_SPYRE_REQUIRE_PRECOMPILED_DECODERS: bool = False
+    VLLM_SPYRE_SIMPLE_COMPILE_BACKEND: str = "eager"
 
 logger = init_logger(__name__)
 
@@ -102,10 +104,9 @@ environment_variables: dict[str, Callable[[], Any]] = {
     # If set, enables the joining of a new sequence even if its prompt length
     # is exceeding the tkv of the current decode batch. As this shifts all the
     # sequences in the decode batch to the right (increasing the tkv), there is
-    # also a potential performance decrease coming with this. The switch allows
-    # to test the feature on realistic workloads before enabling it by default.
+    # also a potential performance decrease coming with this.
     "VLLM_SPYRE_ENABLE_PREFILL_OPTIMIZATION":
-    lambda: bool(int(os.getenv("VLLM_SPYRE_ENABLE_PREFILL_OPTIMIZATION", "0"))
+    lambda: bool(int(os.getenv("VLLM_SPYRE_ENABLE_PREFILL_OPTIMIZATION", "1"))
                  ),
 
     # scheduling heuristic: prefill vs decode prioritization
@@ -114,12 +115,6 @@ environment_variables: dict[str, Callable[[], Any]] = {
     "VLLM_SPYRE_N_TOKENS_PREFILL_PRIO":
     lambda: int(os.getenv("VLLM_SPYRE_N_TOKENS_PREFILL_PRIO", "-1")),
 
-    # scheduling heuristic: maximal waiting (blocking) time for prefill
-    # Prefills waiting longer than VLLM_SPYRE_MAX_WAITING_TIME_SECONDS
-    # seconds will have priority after the current decode batch has finished.
-    "VLLM_SPYRE_MAX_WAITING_TIME_SECONDS":
-    lambda: float(os.getenv("VLLM_SPYRE_MAX_WAITING_TIME_SECONDS", "inf")),
-
     # Allow vllm-spyre to update env vars related to multi-threading (eg. OMP)
     # based on the detected CPU cores and server configuration
     "VLLM_SPYRE_UPDATE_THREAD_CONFIG":
@@ -142,7 +137,20 @@ environment_variables: dict[str, Callable[[], Any]] = {
     # If set, overrides the default (30 minutes) timeout for
     #  torch.distributed.init_process_group
     "VLLM_SPYRE_GLOO_TIMEOUT_MINUTES":
-    lambda: int(os.getenv("VLLM_SPYRE_GLOO_TIMEOUT_MINUTES", "60"))
+    lambda: int(os.getenv("VLLM_SPYRE_GLOO_TIMEOUT_MINUTES", "60")),
+
+    # If set, this will require use of pre-compiled models and
+    # disable compilation for decoders
+    "VLLM_SPYRE_REQUIRE_PRECOMPILED_DECODERS":
+    lambda: bool(int(os.getenv("VLLM_SPYRE_REQUIRE_PRECOMPILED_DECODERS", "0"))
+                 ),
+
+    # Simple compile backend for some dynamically compiled operations, like
+    # gathering logprobs in the sampler.
+    # Defaults to eager, iductor can be used if python headers and a compiler
+    # are available.
+    "VLLM_SPYRE_SIMPLE_COMPILE_BACKEND":
+    lambda: os.getenv("VLLM_SPYRE_SIMPLE_COMPILE_BACKEND", "eager"),
 }
 # --8<-- [end:env-vars-definition]
 
